@@ -26,13 +26,14 @@ import math
 import numpy as np
 from osgeo import gdal
 from .filesystem import now, total_seconds_from, justfname
+from .module_ogr import TransformBBOX, GetSpatialRef
 from .module_s3 import *
 from .module_open import OpenRaster
 from .module_log import Logger
 from .module_memory import mem_usage
 
 
-def GDAL2Numpy(filename, band=1, dtype=np.float32, load_nodata_as=np.nan, bbox=[], verbose=False):
+def GDAL2Numpy(filename, band=1, dtype=np.float32, load_nodata_as=np.nan, bbox=[], bbox_srs=None, verbose=False):
     """
     GDAL2Numpy
     """
@@ -60,26 +61,37 @@ def GDAL2Numpy(filename, band=1, dtype=np.float32, load_nodata_as=np.nan, bbox=[
             data = band.ReadAsArray(0, 0, n, m)
         else:
             x0, px, r0, y0, r1, py = gt
-            X0, Y0, X1, Y1 = bbox
-            print("bbox", bbox)
+            if bbox_srs:
+                X0, Y0, X1, Y1 = TransformBBOX(bbox, bbox_srs, prj)
+            else:
+                X0, Y0, X1, Y1 = bbox
+
             # calcutate starting indices
             j0, i0 = int((X0 - x0) / px), int((Y1 - y0) / py)
             cols, rows = math.ceil((X1 - X0) / px), math.ceil(abs(Y1 - Y0) / abs(py))
+            # assert cols > 0 and rows > 0,
+            cols = max(1, cols)
+            rows = max(1, rows)
 
-            print("mxn", m,"x", n)
-            print("cols, rows", cols, "x", rows)    
+
+            # print("mxn", m,"x", n)
+            # print("cols, rows", cols, "x", rows)   
+            # print("j0, i0", j0, i0) 
 
             # index-safe
             j0, i0 = min(max(j0, 0), n - 1), min(max(i0, 0), m - 1)
-            cols = min(max(cols, 0), n)
-            rows = min(max(rows, 0), m)
+            
+            # index-safe
+            j1, i1 = min(j0 + cols, n), min(i0 + rows, m)
+            # Re-calculate cols and rows
+            cols, rows = j1 - j0, i1 - i0
 
             # re-arrange gt
             k = math.floor((X0 - x0) / px)
             h = math.floor((Y1 - y0) / py)
             gt = x0 + k * px, px, r0, y0 + h * py, r1, py
 
-            print("ReadAsArray(%d,%d,%d,%d)" % (j0, i0, cols, rows))
+            #print("ReadAsArray(%d,%d,%d,%d)" % (j0, i0, cols, rows))
 
             data = band.ReadAsArray(j0, i0, cols, rows)
 
