@@ -95,17 +95,17 @@ def GTiff2Cog(filetif, fileout=None, algo="NEAREST"):
 
         driver = gdal.GetDriverByName("COG")
         if driver:
-            COMPRESSION = "DEFLATE"
+            COMPRESSION = "LZW"
             CO = [f"COMPRESS={COMPRESSION}", "NUM_THREADS=ALL_CPUS"]
             Logger.debug(f"Creating a COG..{CO}")
-            gdal.SetConfigOption("COMPRESS_OVERVIEW", "DEFLATE")
+            gdal.SetConfigOption("COMPRESS_OVERVIEW", "LZW")
             gdal.SetConfigOption("GDAL_CACHEMAX", "512")
             #ds.BuildOverviews('NEAREST', [2, 4, 8, 16, 32])
             ds.BuildOverviews(algo, CalculateOverviews(ds))
             driver.CreateCopy(filetmp, ds, False, CO)
         else:
             BLOCKSIZE = 512
-            COMPRESSION = "DEFLATE"
+            COMPRESSION = "LZW"
             CO = [  "BIGTIFF=YES",
                     "TILED=YES",
                     f"BLOCKXSIZE={BLOCKSIZE}",
@@ -151,7 +151,7 @@ def Numpy2GTiff(arr, gt, prj, fileout, format="GTiff", save_nodata_as=-9999, met
     if format.upper() == "GTIFF":
         CO = ["BIGTIFF=YES", "TILED=YES", "BLOCKXSIZE=512", "BLOCKYSIZE=512", "COMPRESS=LZW"]
     elif format.upper() == "COG":
-        CO = ["BIGTIFF=YES", "COMPRESS=DEFLATE", "NUM_THREADS=ALL_CPUS"]
+        CO = ["BIGTIFF=YES", "COMPRESS=LZW", "NUM_THREADS=ALL_CPUS"]
     else:
         CO = []
 
