@@ -389,9 +389,14 @@ def SaveFeatures(features, fileshp):
         if feature:
             dtype = feature["geometry"]["type"]
             layer = ds.CreateLayer(layername, crs, DATATYPE[dtype])
-            properties = listify(feature["properties"])
+            
+
+            properties = feature["properties"] if feature["properties"] else {}
+            
+            # properties = { "dtm":1.5 , "hello":"world"}
             for name in properties:
-                dtype, dwidth = (properties[name] + ":0").split(":")
+                print(f"<{name}>")
+                dtype, dwidth = (f"{properties[name]}:0").split(":")
                 p, w = math.modf(float(dwidth))
                 p, w = int(p), int(w)
                 field_name = ogr.FieldDefn(name, DATATYPE[dtype])
