@@ -33,13 +33,16 @@ import site
 from osgeo import gdal
 from osgeo import osr, ogr
 from pyproj import CRS
-from .filesystem import justext, juststem, forceext, justpath, strtofile, filetostr, md5text
+from .filesystem import justext, juststem, forceext, justpath, strtofile, filetostr, md5text, listify
 from .module_open import OpenRaster
 from .module_open import OpenShape
 from .module_s3 import isfile
 from .module_log import Logger
 from Levenshtein import distance
 
+shpext = ("shp", "dbf", "shx", "prj", "qpj", "qml", "qix", "idx", "dat", "sbn", "sbx", "fbn", "fbx", "ain", "aih",
+          "atx", "qlr", "mta", "qmd", "cpg")
+
 
 def create_cpg(fileshp):
     """
@@ -56,9 +59,7 @@ def ogr_move(src, dst):
     """
     res = shutil.move(src, dst)
     if "shp" == justext(src).lower():
-        for ext in (
-                "dbf", "shx", "prj", "qpj", "qml", "qix", "idx", "dat", "sbn", "sbx", "fbn", "fbx", "ain", "aih", "atx",
-                "qlr", "mta", "cpg"):
+        for ext in shpext:
             src = forceext(src, ext)
             dst = dst if os.path.isdir(dst) else forceext(dst, ext)
             if os.path.isfile(src):
@@ -75,9 +76,7 @@ def ogr_copy(src, dst):
     """
     res = shutil.copy2(src, dst)
     if "shp" == justext(src).lower():
-        for ext in (
-                "dbf", "shx", "prj", "qpj", "qml", "qix", "idx", "dat", "sbn", "sbx", "fbn", "fbx", "ain", "aih", "atx",
-                "qlr", "mta", "cpg"):
+        for ext in shpext:
             src = forceext(src, ext)
             filedst = forceext(dst, ext)
             filedst = dst if os.path.isdir(dst) else filedst
@@ -96,7 +95,7 @@ def ogr_remove(filename):
         if justext(filename).lower() in ("shp",):
             driver = ogr.GetDriverByName("ESRI Shapefile")
             driver.DeleteDataSource(filename)
-            for ext in ("qlr", "mta", "cpg"):
+            for ext in shpext:
                 fileaux = forceext(filename, ext)
                 if os.path.isfile(fileaux):
                     os.unlink(fileaux)
@@ -166,6 +165,19 @@ def SamePixelSize(filename1, filename2, decimals=-1):
     return size1 == size2
 
 
+def GetDataType(filename):
+    """
+    GetDataType
+    """
+    ds = OpenRaster(filename)
+    if ds:
+        band = ds.GetRasterBand(1)
+        dtype = gdal.GetDataTypeName(band.DataType)
+        ds = None
+        return dtype
+    return None
+
+
 def AutoIdentify(wkt):
     """
     AutoIdentify
@@ -348,16 +360,21 @@ def GetGeometryType(filename):
     return None
 
 
-def Rectangle(minx, miny, maxx, maxy):
+def Rectangle(minx, miny, maxx, maxy, deltaperc=0.0):
     """
     Rectangle - create ogr polygon from bbox
     """
+    deltaperc = min(1.0, max(0.0, abs(deltaperc)))
+    width = abs(maxx - minx)
+    height = abs(maxy - miny)
+    deltax = width * deltaperc
+    deltay = height * deltaperc
     ring = ogr.Geometry(ogr.wkbLinearRing)
-    ring.AddPoint_2D(minx, miny)
-    ring.AddPoint_2D(maxx, miny)
-    ring.AddPoint_2D(maxx, maxy)
-    ring.AddPoint_2D(minx, maxy)
-    ring.AddPoint_2D(minx, miny)
+    ring.AddPoint_2D(minx-deltax, miny-deltay)
+    ring.AddPoint_2D(maxx+deltax, miny-deltay)
+    ring.AddPoint_2D(maxx+deltax, maxy+deltay)
+    ring.AddPoint_2D(minx-deltax, maxy+deltay)
+    ring.AddPoint_2D(minx-deltax, miny-deltay)
     # Create polygon
     poly = ogr.Geometry(ogr.wkbPolygon)
     poly.AddGeometry(ring)
@@ -368,10 +385,12 @@ def TransformBBOX(bbox, s_srs=None, t_srs=None):
     """
     TransformBBOX
     """
+
     if SameSpatialRef(s_srs, t_srs):
         return bbox
-    s_minx, s_miny, s_maxx, s_maxy = bbox
 
+    s_srs = GetSpatialRef(s_srs)
+    t_srs = GetSpatialRef(t_srs)
     if s_srs and s_srs.IsGeographic():
         s_srs.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
     if t_srs and t_srs.IsGeographic():
@@ -382,8 +401,16 @@ def TransformBBOX(bbox, s_srs=None, t_srs=None):
     # rect.Transform(transform)
     # t_minx, t_maxx, t_miny, t_maxy = rect.GetEnvelope()
     # transformed_bbox = (t_minx, t_miny, t_maxx, t_maxy)
-    transformed_bbox = transform.TransformBounds(s_minx, s_miny, s_maxx, s_maxy, 0)
-    return transformed_bbox
+    s_minx, s_miny, s_maxx, s_maxy = bbox
+    minx, miny, maxx, maxy = transform.TransformBounds(s_minx, s_miny, s_maxx, s_maxy, 2)
+
+     # patch for EPSG:6876
+    if SameSpatialRef(t_srs, GetSpatialRef(6876)):
+        minx, miny, maxx, maxy = miny, minx, maxy, maxx
+    elif SameSpatialRef(t_srs, GetSpatialRef(3035)):
+        minx, miny, maxx, maxy = miny, minx, maxy, maxx
+
+    return minx, miny, maxx, maxy
 
 
 def GetExtent(filename, t_srs=None):
@@ -393,11 +420,20 @@ def GetExtent(filename, t_srs=None):
     s_srs = None
     minx, miny, maxx, maxy = 0, 0, 0, 0
     ext = justext(f"{filename}").lower()
-    if isinstance(filename, (list, tuple)):
+    if isinstance(filename, str) and not isfile(filename):
+        # replace ; with , in case of a list of coordinates
+        filename = filename.replace(";", ",")
+        # replace single space with , in case of a list of coordinates
+        filename = re.sub(r"\s+", ",", filename)
+        arr = listify(filename)
+        minx, miny, maxx, maxy = [float(item) for item in arr] if len(arr) == 4 else [0, 0, 0, 0]
+        s_srs = GetSpatialRef(4326)
+    elif isinstance(filename, (list, tuple)) and len(filename) == 4:
         minx, miny, maxx, maxy = filename
         s_srs = GetSpatialRef(4326)
-        s_srs.SetAxisMappingStrategy(osr.OAMS_TRADITIONAL_GIS_ORDER)
-        
+    elif isinstance(filename, ogr.Geometry):
+        minx, maxx, miny, maxy = filename.GetEnvelope()
+        s_srs = filename.GetSpatialReference()
     elif ext == "tif":
         ds = OpenRaster(filename)
         if ds:
@@ -426,10 +462,9 @@ def GetExtent(filename, t_srs=None):
             ds = None
 
     if t_srs and not SameSpatialRef(s_srs, t_srs):
-        s_srs = GetSpatialRef(s_srs)
-        t_srs = GetSpatialRef(t_srs)
-        transform = osr.CoordinateTransformation(s_srs, t_srs)
-        minx, miny, maxx, maxy = transform.TransformBounds(minx, miny, maxx, maxy, 0)
+
+        minx, miny, maxx, maxy = TransformBBOX([minx, miny, maxx, maxy], s_srs, t_srs)
+        #print(f"GetExtent: {minx}, {miny}, {maxx}, {maxy}")
 
     return minx, miny, maxx, maxy
 
